@@ -3,7 +3,7 @@
  *	x86asm.h
  *
  *	Copyright (C) 1999-2002 Stefan Weyergraf
- *	Copyright (C) 2005 Sebastian Biallas (sb@biallas.net)
+ *	Copyright (C) 2005-2007 Sebastian Biallas (sb@biallas.net)
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -33,7 +33,7 @@ struct x86asm_insn {
 	char opsizeprefix;
 	char n[16];
 	char *name;
-	x86_insn_op op[3];
+	x86_insn_op op[5];
 };
 
 struct x86addrcoding {
@@ -54,10 +54,11 @@ public:
 	X86OpSize opsize;
 	X86AddrSize addrsize;
 protected:
-	int esizes[3];
+	int esizes[5];
 
 	int modrmv;
 	int sibv;
+	int vexvvvv;
 	uint64 disp;
 	int dispsize;
 	int disppos;
@@ -65,12 +66,15 @@ protected:
 	int imm2;
 	int immsize;
 	uint8 rexprefix; // 0 = no, 0x80 = forbid, 0x40 = yes
+	int drexdest;
+	int drexoc0;
 	uint64 address;
 	bool ambiguous;
 	bool namefound;
-	bool addrsize_depend;
+	static x86opc_insn (*x86_32a_insns)[256];
 	x86opc_insn (*x86_insns)[256];
 
+		void prepInsns();
 	virtual x86dis *createCompatibleDisassembler();
 	void delete_nonsense(CPU_ADDR addr);
 	bool delete_nonsense_insn(asm_code *c, x86dis *dis, CPU_ADDR addr);
@@ -85,6 +89,7 @@ protected:
 	void emitsib_index(int index);
 	void emitsib_scale(int scale);
 	bool encode_insn(x86asm_insn *insn, x86opc_insn *opcode, int opcodeb, int additional_opcode, int prefix, int eopsize, int eaddrsize);
+	bool encode_vex_insn(x86asm_insn *insn, x86opc_vex_insn *opcode, int opcodeb, int additional_opcode, int opsize, int addrsize);
 	bool encode_modrm(x86_insn_op *op, char size, bool allow_reg, bool allow_mem, int eopsize, int eaddrsize);
 	bool encode_modrm_v(const x86addrcoding (*modrmc)[3][8], x86_insn_op *op, int mindispsize, int *mod, int *rm, int *dispsize);
 	bool encode_op(x86_insn_op *op, x86opc_insn_op *xop, int *esize, int eopsize, int eaddrsize);
@@ -94,12 +99,15 @@ protected:
 	char flsz2hsz(int size);
 	const char *immlsz2hsz(int size, int opsize);
 	const char *lsz2hsz(int size, int opsize);
-	int match_allops(x86asm_insn *insn, x86opc_insn *xinsn, int opsize, int addrsize);
+	int match_allops(x86asm_insn *insn, byte *xop, int maxops, int opsize, int addrsize);
 	void match_fopcodes(x86asm_insn *insn);
 	void match_opcode(x86opc_insn *opcode, x86asm_insn *insn, int prefix, byte opcodebyte, int additional_opcode, int def_match);
+	void match_vex_opcode(x86opc_vex_insn *opcode, x86asm_insn *insn, byte opcodebyte, int additional_opcode);
 	int match_opcode_name(const char *input_name, const char *opcodelist_name, int def_match);
 	int match_opcode_final(x86opc_insn *opcode, x86asm_insn *insn, int prefix, byte opcodebyte, int additional_opcode, int opsize, int addrsize, int match);
+	int match_vex_opcode_final(x86opc_vex_insn *opcode, x86asm_insn *insn, byte opcodebyte, int additional_opcode, int opsize, int addrsize);
 	void match_opcodes(x86opc_insn *opcodes, x86asm_insn *insn, int prefix, int def_match);
+	void match_vex_opcodes(x86asm_insn *insn);
 	bool match_size(x86_insn_op *op, x86opc_insn_op *xop, int opsize);
 	int match_type(x86_insn_op *op, x86opc_insn_op *xop, int addrsize);
 	bool opfarptr(x86_insn_op *op, const char *xop);
@@ -109,10 +117,11 @@ protected:
 	virtual bool opreg(x86_insn_op *op, const char *xop);
 	bool opmmx(x86_insn_op *op, const char *xop);
 	virtual bool opxmm(x86_insn_op *op, const char *xop);
+	virtual bool opymm(x86_insn_op *op, const char *xop);
 	bool opseg(x86_insn_op *op, const char *xop);
 	bool opspecialregs(x86_insn_op *op, const char *xop);
 	int simmsize(uint64 imm, int immsize);
-	void splitstr(const char *s, char *name, int size, char *op[3], int opsize);
+	void splitstr(const char *s, char *name, int size, char *op[5], int opsize);
 	void tok(const char **s, char *res, int reslen, const char *sep);
 public:
 		x86asm(X86OpSize opsize, X86AddrSize addrsize);
@@ -131,6 +140,7 @@ public:
 		x86_64asm();
 	virtual bool opreg(x86_insn_op *op, const char *xop);
 	virtual bool opxmm(x86_insn_op *op, const char *xop);
+	virtual bool opymm(x86_insn_op *op, const char *xop);
 		void prepInsns();
 protected:
 	virtual x86dis *createCompatibleDisassembler();
