@@ -3,7 +3,7 @@
  *	x86opc.h
  *
  *	Copyright (C) 1999-2002 Stefan Weyergraf
- *	Copyright (C) 2005-2006 Sebastian Biallas (sb@biallas.net)
+ *	Copyright (C) 2005-2007 Sebastian Biallas (sb@biallas.net)
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -55,24 +55,26 @@ enum X86AddrSize {
 	X86_ADDRSIZE64 = 2,
 };
 
-#define X86_OPTYPE_EMPTY	0
-#define X86_OPTYPE_IMM		1
-#define X86_OPTYPE_REG		2
-#define X86_OPTYPE_SEG		3
-#define X86_OPTYPE_MEM		4
-#define X86_OPTYPE_CRX		5
-#define X86_OPTYPE_DRX		6
-#define X86_OPTYPE_TRX		7
-#define X86_OPTYPE_STX		8
-#define X86_OPTYPE_MMX		9
-#define X86_OPTYPE_XMM		10
-#define X86_OPTYPE_FARPTR	11
+enum X86_Optype {
+	X86_OPTYPE_EMPTY = 0,
+	X86_OPTYPE_IMM = 1,
+	X86_OPTYPE_REG = 2,
+	X86_OPTYPE_SEG = 3,
+	X86_OPTYPE_MEM = 4,
+	X86_OPTYPE_CRX = 5,
+	X86_OPTYPE_DRX = 6,
+	X86_OPTYPE_STX = 7,
+	X86_OPTYPE_MMX = 8,
+	X86_OPTYPE_XMM = 9,
+	X86_OPTYPE_YMM = 10,
+	X86_OPTYPE_FARPTR = 11,
 
-// user defined types start here
-#define X86_OPTYPE_USER		32
+	// user defined types start here
+	X86_OPTYPE_USER = 32,
+};
 
 struct x86_insn_op {
-	int type;
+	X86_Optype type;
 	int size;
 	bool need_rex;
 	bool forbid_rex;
@@ -100,6 +102,7 @@ struct x86_insn_op {
 		int stx;
 		int mmx;
 		int xmm;
+		int ymm;
 		union {
 			int i;
 			void *p;
@@ -114,9 +117,12 @@ enum {
 	TYPE_C,		/* reg of ModR/M picks control register */
 	TYPE_D,		/* reg of ModR/M picks debug register */
 	TYPE_E,		/* ModR/M (general reg or memory) */
+	TYPE_F,		/* r/m of ModR/M picks a fpu register */
+	TYPE_Fx,	/* extra picks a fpu register */
 	TYPE_G,		/* reg of ModR/M picks general register */
 	TYPE_Is,	/* signed immediate */
 	TYPE_I,		/* unsigned immediate */
+	TYPE_I4,	/* 4 bit immediate (see TYPE_VI, TYPE_YI) */
 	TYPE_Ix,	/* fixed immediate */
 	TYPE_J,		/* relative branch offset */
 	TYPE_M,		/* ModR/M (memory only) */
@@ -130,13 +136,38 @@ enum {
 	TYPE_RXx,	/* extra picks register, no REX extension */
 	TYPE_S,		/* reg of ModR/M picks segment register */
 	TYPE_Sx,	/* extra picks segment register */
-	TYPE_T,		/* reg of ModR/M picks test register */
+
 	TYPE_V,		/* reg of ModR/M picks XMM register */
+	TYPE_VI,	/* bits 7-4 of imm picks XMM register */
+	TYPE_VV,	/* VEX.vvvv pick XMM register */
 	TYPE_Vx,	/* extra picks XMM register */
 	TYPE_VR,	/* rm of ModR/M picks XMM register */
 	TYPE_W,		/* ModR/M (XMM reg or memory) */
-	TYPE_F,		/* r/m of ModR/M picks a fpu register */
-	TYPE_Fx,	/* extra picks a fpu register */
+
+	TYPE_Y,		/* reg of ModR/M picks YMM register */
+	TYPE_YV,	/* VEX.vvvv pick YMM register */
+	TYPE_YI,	/* bits 7-4 of imm picks YMM register */
+	TYPE_YR,	/* rm of ModR/M picks YMM register */
+	TYPE_X,		/* ModR/M (YMM reg or memory) */
+
+	TYPE_VD,	/* SSE5: drex.dest */
+	TYPE_VS,	/* SSE5: src (mod/rm) */
+};
+
+enum X86_VEX {
+	W0    = 0x00,
+	W1    = 0x80,
+	
+	_128  = 0x00,
+	_256  = 0x40,
+	
+	_66   = 0x01,
+	_f3   = 0x02,
+	_f2   = 0x03,
+	
+	_0f   = 0x10,
+	_0f38 = 0x20,
+	_0f3a = 0x30,
 };
 
 /* when name is == 0, the first op has a special meaning (layout see x86_insn_op_special) */
@@ -156,7 +187,7 @@ enum {
 	SIZE_Q = 'q',		/* qword */
 	SIZE_U = 'u',		/* qword OR oword (depending on 0x66 prefix) */
 	SIZE_Z = 'z',		/* dword OR qword (depending on 0x66 prefix) */
-	SIZE_O = 'o',		/* oword */
+	SIZE_O = 'o',		/* oword (128 bit) */
 	SIZE_V = 'v',		/* word OR dword OR qword */
 	SIZE_VV = 'V',		/* word OR dword OR sign extended dword */
 	SIZE_R = 'r',		/* dword OR qword (depending on rex size) */
@@ -165,9 +196,9 @@ enum {
 	SIZE_L = 'l',		/* long/double real (64-bit) */
 	SIZE_T = 't',		/* temp/extended real (80-bit) */
 	SIZE_A = 'a',		/* packed decimal (80-bit BCD) */
+	SIZE_Y = 'y',		/* ymmword (256 bit) */
 };
 
-#define INFO_PREFIX_66		0x66
 #define INFO_DEFAULT_64		0x80
 
 struct x86opc_insn_op {
@@ -182,6 +213,12 @@ struct x86opc_insn {
 	byte op[4];
 };
 
+struct x86opc_vex_insn {
+	const char *name;
+	byte vex;
+	byte op[5];
+};
+
 struct x86_64_insn_patch {
 	int opc;
 	x86opc_insn insn;
@@ -214,9 +251,11 @@ struct x86opc_finsn {
 #define X86_REG_R15		15
 #define X86_REG_IP		66
 
-#define X86_OPC_GROUPS		5
-#define X86_GROUPS		27
-#define X86_SPECIAL_GROUPS	7
+#define X86_OPC_GROUPS		9
+#define X86_SPECIAL_GROUPS	13
+
+extern x86opc_insn x86_les;
+extern x86opc_insn x86_lds;
 
 extern const char *x86_regs[4][8];
 extern const char *x86_64regs[4][16];
@@ -230,8 +269,10 @@ extern x86opc_insn x86_insns_ext_66[256];
 extern x86opc_insn x86_insns_ext_f2[256];
 extern x86opc_insn x86_insns_ext_f3[256];
 extern x86opc_insn x86_opc_group_insns[X86_OPC_GROUPS][256];
-extern x86opc_insn x86_group_insns[X86_GROUPS][8];
+extern x86opc_insn x86_group_insns[][8];
 extern x86opc_insn x86_special_group_insns[X86_SPECIAL_GROUPS][9];
+extern x86opc_vex_insn *x86_vex_insns[256];
+extern x86opc_vex_insn x86_group_vex_insns[][8];
 
 extern x86opc_insn x86_modfloat_group_insns[8][8];
 extern x86opc_finsn x86_float_group_insns[8][8];
