@@ -20,7 +20,7 @@
 #ifndef __CSTREAM_H__
 #define __CSTREAM_H__
 
-#include "global.h"
+#include "io/types.h"
 #include "stream.h"
 
 /*
@@ -29,20 +29,20 @@
  
 #define COMPRESSED_STREAM_DEFAULT_GRANULARITY 10240
 
-class ht_compressed_stream: public ht_layer_stream {
+class CompressedStream: public StreamLayer {
 protected:
 	byte *buffer;
-	UINT buffersize;
-	UINT bufferpos;
+	uint buffersize;
+	uint bufferpos;
 public:
-			void	init(ht_stream *stream, bool own_stream, UINT granularity=COMPRESSED_STREAM_DEFAULT_GRANULARITY);
-	virtual	void	done();
+			CompressedStream(Stream *stream, bool own_stream);
+	virtual		~CompressedStream();
 /* overwritten */
-	virtual	UINT	read(void *buf, UINT size);
-	virtual	UINT	write(const void *buf, UINT size);
+	virtual	uint	read(void *buf, uint size);
+	virtual	uint	write(const void *buf, uint size);
 protected:
-			bool flush_compressed();
-			bool flush_uncompressed();
+			void flush_compressed();
+			void flush_uncompressed();
 };
 
 #endif
