@@ -474,12 +474,12 @@ protected:
 	uint line_length;
 	uint uid;
 public:
-		void init(File *file, FileOfs ofs, FileOfs size, uint line_length, uint uid, uint disp=0);
+		void init(File *file, FileOfs ofs, FileOfs size, uint line_length, uint uid, int disp=-1);
 		int  get_line_length();
 		void set_line_length(uint line_length);
 		int  get_disp();
 		void set_disp(uint disp);
-/* overwritten */
+	/* overwritten */
 	virtual	bool convert_ofs_to_id(const FileOfs offset, LINE_ID *line_id);
 	virtual	bool convert_id_to_ofs(const LINE_ID line_id, FileOfs *offset);
 	virtual	void first_line_id(LINE_ID *line_id);
